.. Duedil documentation master file, created by
   sphinx-quickstart on Fri Feb 27 11:28:50 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Duedil Python API
=================

.. automodule:: duedil

Contents:
---------

Check out each module to get an insight of what do you have access to:

.. toctree::
   :maxdepth: 2

   client
   cache



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

